@@ -246,4 +246,4 @@ class CollectionCloner:
         try:
             des_collection.insert_many(src_docs)
         except Exception as e:
-            logger.debug('Could not insert document into destination collection')
\ No newline at end of file
+            logger.debug(e)
\ No newline at end of file
